function syncModel( mdlName, explorer )
% autosar.api.syncModel Synchronize the Simulink-AUTOSAR mapping of a model with
% updated blocks.
% 
% autosar.api.syncModel(MDLNAME) synchronizes the Simulink-AUTOSAR mapping for
% data transfers, entry-point functions and function callers for model MDLNAME.
%
% Examples:
%
% To synchronize the Simulink-AUTOSAR mapping with a model
%    autosar.api.syncModel('rtwdemo_autosar_counter');
%
% See also autosar.api.getSimulinkMapping

%   Copyright 2015 The MathWorks, Inc.

if nargin < 2
    explorer = autosar.ui.utils.findExplorer(autosar.api.Utils.m3iModel(mdlName));
end

% Interleave synchronizing the mapping and UI (if opened)
mapping = autosar.api.Utils.modelMapping(mdlName);

% Initial sync
mapping.sync();
i_uiUpdateAndRefresh(@autosar.ui.utils.updateFcnCallers, mapping, explorer);

% Following syncs need model to be compiled
compiledModelCleanupObj = autosar.validation.CompiledModelUtils.forceCompiledModel(mdlName);

% Sync step functions
mapping.syncStepFunctions();
i_uiUpdateAndRefresh(@autosar.ui.utils.updateStepFunctions, mapping, explorer);

% Sync data transfers
mapping.syncDataTransfers();
i_uiUpdateAndRefresh(@autosar.ui.utils.updateDataTransfers, mapping, explorer);

% End compiled model stage
compiledModelCleanupObj.delete();



function i_uiUpdateAndRefresh(uiUpdateFcn, mapping, explorer)
% Update ui node (if open) with mapping

if isempty(explorer)
    return
end

uiUpdateFcn(mapping, explorer);
mappingRoot = explorer.MappingRoot;
mappingRoot.RefreshUI(mappingRoot);

% LocalWords:  MDLNAME
