classdef ConfigSetFinalValidator < autosar.validation.PhasedValidator
% ConfigSetValidator

%   Copyright 2013-2014 The MathWorks, Inc.

    methods (Access=protected)
        
        function verifyFinal(this, hModel)
            % Following depend on engine interface
            this.verifyMultiTaskingMode(hModel);
            this.verifyAsyncMode(hModel);
            if slfeature('AllowConstantRootOutportForAUTOSAR') == 0
                this.verifyRootOutPortsNonConstant(hModel);
            end
        end
        
    end
    
    methods (Static, Access=private)
        
        function verifyMultiTaskingMode(hModel)
        % Function: verifyMultiTaskingMode =============================
        % Abstract: [Engine Interface] Verify settings for multitasking model
            
            % Engine interface will implicitly put model into a compiled state for this
            % sample time check. However for performance assert that the model
            % is precompiled.
            assert(autosar.validation.CompiledModelUtils.isCompiled(hModel));
            
            sess = Simulink.CMI.EIAdapter(1);
            uddobj = get_param(hModel, 'UDDObject');
            singleRate = uddobj.outputFcnHasSinglePeriodicRate();
            delete(sess);

            if  ~singleRate && ~strcmp(get_param(hModel, 'SolverMode'), 'SingleTasking')
                % Multi-tasking mode    
               
                % Cannot use obsoleted RTW.AutosarInterface class for mapping
                if ~autosar.api.Utils.isMapped(hModel)
                    DAStudio.error('RTW:autosar:expectAutosarInterface');
                end
                
            end
            
        end
    
        function verifyAsyncMode(hModel)
        % Function: verifyAsyncMode =============================
        % Abstract: [Engine Interface] Error out for top-model async-rating system.

            % Engine interface will implicitly put model into a compiled state for this
            % sample time check. However for performance assert that the model
            % is precompiled.
            assert(autosar.validation.CompiledModelUtils.isCompiled(hModel));
            
            sess = Simulink.CMI.EIAdapter(1);
            uddobj = get_param(hModel, 'UDDObject');
            asyncRates = uddobj.outputFcnHasAsyncRates();
            delete(sess);

            isExportFcn = autosar.validation.ExportFcnValidator.isExportFcn(hModel);
            
            if asyncRates && ~isExportFcn
                msg = DAStudio.message('RTW:autosar:asyncAUTOSAR');
                DAStudio.error('RTW:fcnClass:finish', msg);
            end
        
        end
    
        function verifyRootOutPortsNonConstant(hModel)
        % Function: verifyRootOutPortsNonConstant =============================
        % Abstract: [Compiled] verify root outports are not constant
            
            outpH = find_system(hModel, 'SearchDepth', 1, 'Type', 'block',...
                                'BlockType', 'Outport');

            for i=1:length(outpH)
                outBlk = outpH(i);
                compiledSampleTime = get_param(outBlk, 'CompiledSampleTime');
                if isinf(compiledSampleTime(1)) &&...
                        ((~slfeature('DecoupleConstantSampleTimeAndTunableParameters')) ||...
                         isinf(compiledSampleTime(2)))
                    msg = DAStudio.message('RTW:autosar:constantRootOutport', ...
                                           getfullname(outBlk));
                    DAStudio.error('RTW:fcnClass:finish',msg);
                end
            end
            
        end
    
    end

end

% LocalWords:  Validator Async async
