function updateReferences(this, modelName, varargin)
% UPDATEREFERENCES(THIS, MODELNAME, P1, V1, ...) updates model MODELNAME with
% references in imported AUTOSAR description defined in arxml.importer object
% THIS. The import generates  a report that details the updates applied to the
% model. User can control import of AUTOSAR references with Name-Value pairs
% P1, V1 etc.
 
% Note: This api is different from updateModel() which requires input arxml
% to have AUTOSAR software component mapped by the model. 
 
% Example:  
% Update model 'myModel.slx' with references to AUTOSAR elements 
% CompuMethods, Units, Dimensions, ImplementationDataTypes and SwBaseTypes
% described in arxml files 'CM.arxml', 'Units.arxml', 'Dimension.arxml',
% 'Platform_Types.arxml' and 'PlatformBase_Types.arxml' resp.
%   
% arxml_files = {'CM.arxml', 'Unit.arxml', 'Dimension.arxml',...
%   'Platform_Types.arxml', 'PlatformBase_Types.arxml'}; 
% obj = arxml.importer(arxml_files); 
% obj.updateReferences('myModel');
%
% If the user wants to import all CompuMethod references from a package, then 
% use Following Name-Value pair. 
% Example:  
% obj.updateReferences ('myModel', 'Category', {'ImplementationDataType'}  
%  'Package', {'/AUTOSAR_PlatformTypes/ImplementationDataTypes'}); 
%  
% If the user wants to import element references using packageable path, then 
% Use following Name-Value pair. 
% Example:  
% obj.updateReferences('myModel', 'RootPath', {'/pkg/CompuMethodPackage/CM1',...
%   '/AUTOSAR_PlatformTypes/ImplementationDataTypes/uint16'});
%
% When a element reference is imported, all of its dependencies are also 
% imported. For example importing a CompuMethod reference also imports 
% Unit reference and PhysicalDimension reference. Similarly Importing
% ImplementationDataType also imports SwBaseType reference.

%   Copyright 2014-2015 The MathWorks, Inc.

% Check function arguments
argParser = inputParser;
argParser.addRequired('ModelName', @ischar);
argParser.addParameter('Category', {}, @(x)(iscell(x)));
argParser.addParameter('RootPath', {}, @(x)(iscell(x)));
argParser.addParameter('Package', {}, @(x)(iscell(x)));
argParser.parse(modelName, varargin{:});

% Strip out any extension that user may have passed in
[~, modelName] = fileparts(modelName);
args = {...
    'Category', argParser.Results.Category,...
    'RootPath', argParser.Results.RootPath,...
    'Package', argParser.Results.Package,...
    'UpdateReferences', true,...
    };
    
p_updateModel(this, modelName, args{:});

% LocalWords:  MODELNAME Compu packageable Sw
